<?php

namespace SGalinski\SgJobs\Controller\Ajax;

use SGalinski\SgAjax\Controller\Ajax\AbstractAjaxController;
use SGalinski\SgComments\Domain\Service\FileAndFolderService;
use TYPO3\CMS\Core\Core\Environment;
use TYPO3\CMS\Core\Utility\GeneralUtility;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Uploads for the applicationForm
 */
class UploadController  extends AbstractAjaxController {

	public const TYPO3_TMP_FOLDER = 'typo3temp/';

	/**
	 * Returns the calculated max file size.
	 *
	 * @return int
	 */
	protected function getMaxFileSize(): int {
		$maxFileSize = (int) $this->settings['fileUpload']['maxfileSize'];
		if ($maxFileSize <= 0 && isset($GLOBALS['TYPO3_CONF_VARS']['BE']['maxFileSize'])) {
			$maxFileSize = (int) $GLOBALS['TYPO3_CONF_VARS']['BE']['maxFileSize']; // Example value: 800000
			return ($maxFileSize * 1000);
		}

		return $maxFileSize * 1000 * 1000;
	}

	/**
	 * Uploads a new coverletter.
	 *
	 * @return void
	 * @throws \TYPO3\CMS\Core\Resource\Exception\ExistingTargetFileNameException
	 * @throws \InvalidArgumentException
	 */
	public function uploadCoverletterAction() {
		$this->handleAnyDropZoneUpload();
	}

	/**
	 * Uploads a new cd.
	 *
	 * @return void
	 * @throws \TYPO3\CMS\Core\Resource\Exception\ExistingTargetFileNameException
	 * @throws \InvalidArgumentException
	 */
	public function uploadCvAction() {
		$this->handleAnyDropZoneUpload();
	}

	/**
	 * Uploads a new cd.
	 *
	 * @return void
	 * @throws \TYPO3\CMS\Core\Resource\Exception\ExistingTargetFileNameException
	 * @throws \InvalidArgumentException
	 */
	public function uploadCertificateAction() {
		$this->handleAnyDropZoneUpload();
	}


	private function handleAnyDropZoneUpload(){
		$success = FALSE;
		$filePath = '';
		if (\count($_FILES) > 0) {
			$firstFile = current($_FILES);
			$pathInfo = pathinfo($firstFile['name']);

			$fileAndFolderService = $this->objectManager->get(FileAndFolderService::class);
			$storage = $fileAndFolderService->getStorage();
			$fileName = $storage->sanitizeFileName(
				strtolower(
					str_replace(' ', '_', trim($pathInfo['filename'] . '.' . strtolower($pathInfo['extension'])))
				)
			);

			$filePath = Environment::getPublicPath() . '/' . self::TYPO3_TMP_FOLDER . $fileName;
			$tempFilePath = $firstFile['tmp_name'];
			$success = GeneralUtility::upload_copy_move($tempFilePath, $filePath);
		}

		$this->returnData(
			[
				'success' => $success,
				'path' => $filePath,
			]
		);
	}
}
